@@ -2,7 +2,7 @@ package Bread::Board::Service::Inferred;
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
 
-our $VERSION   = '0.18';
+our $VERSION   = '0.19';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use Try::Tiny;
@@ -15,6 +15,12 @@ has 'current_container' => (
     required => 1,
 );
 
+has 'service' => (
+    is        => 'ro',
+    isa       => 'Bread::Board::ConstructorInjection',
+    predicate => 'has_service',
+);
+
 has 'service_args' => (
     is      => 'ro',
     isa     => 'HashRef',
@@ -48,7 +54,26 @@ sub infer_service {
         || confess 'Only class types, role types, or subtypes of Object can be inferred. '
                  . 'I don\'t know what to do with type (' . $type_constraint->name . ')';
 
-    my %params = %{ $self->service_args };
+    my %params = (
+        name => 'type:' . $type,
+    );
+
+    if ($self->has_service) {
+        my $service = $self->service;
+        %params = (
+            %params,
+            name         => $service->name,
+            class        => $service->class,
+            dependencies => $service->dependencies,
+            parameters   => $service->parameters,
+        );
+    }
+    else {
+        %params = (
+            %params,
+            %{ $self->service_args }
+        );
+    }
 
     # if the class is specified, then
     # we can use that reliably, otherwise
@@ -68,11 +93,8 @@ sub infer_service {
         }
     }
 
-    my $meta = try {
-        $params{'class'}->meta
-    } catch {
-        confess "Could not get the meta object for class(" . $params{'class'} . ")";
-    };
+    my $meta = Class::MOP::class_of($params{'class'})
+        || confess "Could not get the meta object for class(" . $params{'class'} . ")";
 
     ($meta->isa('Moose::Meta::Class'))
         || confess "We can only infer Moose classes"
@@ -88,7 +110,7 @@ sub infer_service {
     $params{'parameters'}   ||= {};
 
     # defer this for now ...
-    $seen->{ $type } = undef;
+    $seen->{ $type } = $params{'name'};
 
     foreach my $attribute (@required_attributes) {
         my $name = $attribute->name;
@@ -105,7 +127,7 @@ sub infer_service {
             $service = $current_container->get_type_mapping_for( $type_name )
         }
         elsif ( exists $seen->{ $type_name } ) {
-            if ( defined $seen->{ $type_name } ) {
+            if ( blessed($seen->{ $type_name }) ) {
                 # if the type has already been
                 # inferred, then we use it
                 $service = $seen->{ $type_name };
@@ -114,7 +136,9 @@ sub infer_service {
                 # if not, then we have to use
                 # the built in laziness and
                 # make it a dependency
-                $service = Bread::Board::Dependency->new( service_path => ('type:' . $type_name) );
+                $service = Bread::Board::Dependency->new(
+                    service_path => $seen->{ $type_name }
+                );
             }
         }
         else {
@@ -164,10 +188,13 @@ sub infer_service {
     # infer. No other type of
     # injection makes sense here.
     # - SL
-    my $service = Bread::Board::ConstructorInjection->new(
-        name => ('type:' . $type),
-        %params
-    );
+    my $service;
+    if ($self->has_service) {
+        $service = $self->service->clone(%params);
+    }
+    else {
+        $service = Bread::Board::ConstructorInjection->new(%params);
+    }
 
     # NOTE:
     # We need to do this so that
